[libpng15] Imported from libpng-1.5.7beta03.tar
diff --git a/LICENSE b/LICENSE
index 9db2f71..5e76ace 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 16, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 17, 2011, are
 Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-November 16, 2011
+November 17, 2011
diff --git a/Makefile.am b/Makefile.am
index 49e4e2c..02d4557 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -12,16 +12,19 @@
 AUTOMAKE_OPTIONS = foreign
 
 # test programs - run on make check, make distcheck
-check_PROGRAMS= pngtest pngvalid pngstest
+check_PROGRAMS= pngtest pngvalid
 pngtest_SOURCES = pngtest.c
 pngtest_LDADD = libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.la
 pngvalid_SOURCES = pngvalid.c
 pngvalid_LDADD = libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.la
+TESTS = test-pngtest.sh test-pngvalid-simple.sh test-pngvalid-full.sh
+TESTS_ENVIRONMENT= srcdir=$(srcdir)
+
+# Do the following only if the contrib directory is present.
+check_PROGRAMS+= pngstest
 pngstest_SOURCES = contrib/libtests/pngstest.c
 pngstest_LDADD = libpng@PNGLIB_MAJOR@@PNGLIB_MINOR@.la
-TESTS = test-pngtest.sh test-pngvalid-simple.sh test-pngvalid-full.sh \
-	test-pngstest.sh
-TESTS_ENVIRONMENT= srcdir=$(srcdir)
+TESTS += test-pngstest.sh
 
 # man pages
 dist_man_MANS= libpng.3 libpngpf.3 png.5
diff --git a/README b/README
index 7d8dc17..7856047 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.7beta03 - November 16, 2011 (shared library 15.0)
+README for libpng version 1.5.7beta03 - November 17, 2011 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/arm/filter_neon.S b/arm/filter_neon.S
index 1f10328..63a5d8c 100644
--- a/arm/filter_neon.S
+++ b/arm/filter_neon.S
@@ -1,7 +1,8 @@
 
 /* filter_neon.S - NEON optimised filter functions
  *
- * Copyright (c) 2011 Mans Rullgard
+ * Copyright (c) 2011 Glenn Randers-Pehrson
+ * Written by Mans Rullgard, 2011.
  *
  * This code is released under the libpng license.
  * For conditions of distribution and use, see the disclaimer
diff --git a/contrib/libtests/pngstest.c b/contrib/libtests/pngstest.c
index 9b983ce..103a68b 100644
--- a/contrib/libtests/pngstest.c
+++ b/contrib/libtests/pngstest.c
@@ -18,6 +18,13 @@
 
 #include "../sRGBtables/sRGB.h"
 
+/* The following is to support direct compilation of this file as C++ */
+#ifdef __cplusplus
+#  define voidcast(type, value) static_cast<type>(value)
+#else
+#  define voidcast(type, value) (value)
+#endif /* __cplusplus */
+
 /* Math support - neither Cygwin nor Visual Studio have C99 support and we need
  * a predictable rounding function, so make one here:
  */
@@ -261,7 +268,7 @@
    if (size+32 > image->bufsize)
    {
       freebuffer(image);
-      image->buffer = malloc(size+32);
+      image->buffer = voidcast(png_bytep, malloc(size+32));
       if (image->buffer == NULL)
       {
          fprintf(stderr,
@@ -1336,7 +1343,7 @@
 
                if (cb >= 0 && (unsigned long int)cb < (size_t)~(size_t)0)
                {
-                  png_bytep b = malloc((size_t)cb);
+                  png_bytep b = voidcast(png_bytep, malloc((size_t)cb));
 
                   if (b != NULL)
                   {
diff --git a/libpng-manual.txt b/libpng-manual.txt
index a383ae1..2402c84 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.7beta03 - November 16, 2011
+ libpng version 1.5.7beta03 - November 17, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.7beta03 - November 16, 2011
+ libpng versions 0.97, January 1998, through 1.5.7beta03 - November 17, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -4566,7 +4566,7 @@
 
 XIV. Y2K Compliance in libpng
 
-November 16, 2011
+November 17, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index 0816efc..31f4f68 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "November 16, 2011"
+.TH LIBPNG 3 "November 17, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.7beta03
 .SH SYNOPSIS
@@ -1037,7 +1037,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.7beta03 - November 16, 2011
+ libpng version 1.5.7beta03 - November 17, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -1048,7 +1048,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.7beta03 - November 16, 2011
+ libpng versions 0.97, January 1998, through 1.5.7beta03 - November 17, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -5604,7 +5604,7 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-November 16, 2011
+November 17, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -5869,7 +5869,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.7beta03 - November 16, 2011:
+Libpng version 1.5.7beta03 - November 17, 2011:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5892,7 +5892,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 16, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 17, 2011, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5991,7 +5991,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-November 16, 2011
+November 17, 2011
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 7a6fd7d..26e891b 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "November 16, 2011"
+.TH LIBPNGPF 3 "November 17, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.7beta03
 (private functions)
diff --git a/png.5 b/png.5
index 8235fe3..7cb2997 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "November 16, 2011"
+.TH PNG 5 "November 17, 2011"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/pngconf.h b/pngconf.h
index 1a84cb2..b933ae9 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.7beta03 - November 16, 2011
+ * libpng version 1.5.7beta03 - November 17, 2011
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index b1e89c5..262cf12 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.7beta03 - November 16, 2011
+libpng version 1.5.7beta03 - November 17, 2011
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 2854675..b18338c 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.7beta03 - November 16, 2011
+ * libpng version 1.5.7beta03 - November 17, 2011
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 5510ff7..09dfd27 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.5.7beta03 - November 16, 2011
+Makefiles for  libpng version 1.5.7beta03 - November 17, 2011
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index e5fccbb..894484d 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -3,7 +3,7 @@
 
 /* pnglibconf.h - library build configuration */
 
-/* Libpng 1.5.7beta03 - November 16, 2011 */
+/* Libpng 1.5.7beta03 - November 17, 2011 */
 
 /* Copyright (c) 1998-2011 Glenn Randers-Pehrson */
 
diff --git a/test-pngvalid-full.sh b/test-pngvalid-full.sh
index cf0e41a..f7d1b2b 100755
--- a/test-pngvalid-full.sh
+++ b/test-pngvalid-full.sh
@@ -18,6 +18,4 @@
    fi
 done
 
-echo
-
 exit $err
diff --git a/png.h b/png.h
index 9896e0c..0101ef5 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.7beta03 - November 16, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.7beta03 - November 16, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -195,7 +195,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 16, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -307,7 +307,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    November 16, 2011
+ *    November 17, 2011
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -373,7 +373,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.5.7beta03"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.7beta03 - November 16, 2011\n"
+     " libpng version 1.5.7beta03 - November 17, 2011\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.7beta03 - November 16, 2011
+ * libpng version 1.5.7beta03 - November 17, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.7beta03 - November 16, 2011: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.7beta03 - November 17, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -195,7 +195,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 16, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 17, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5